@@ -33,7 +33,7 @@ from ..io.resources import (
     resolve_custom_path, use_cdn,
 )
 from ..io.save import save
-from ..io.state import curdoc_locked, state
+from ..io.state import set_curdoc, state
 from ..layout import Column, GridSpec, ListLike
 from ..models.comm_manager import CommManager
 from ..pane import (
@@ -44,6 +44,7 @@ from ..reactive import ReactiveHTML
 from ..theme.base import (
     THEMES, DefaultTheme, Design, Theme,
 )
+from ..theme.native import Native
 from ..util import isurl
 from ..viewable import (
     MimeRenderMixin, Renderable, ServableMixin, Viewable,
@@ -119,6 +120,12 @@ class BaseTemplate(param.Parameterized, MimeRenderMixin, ServableMixin, Resource
         }
         self._render_items: dict[str, tuple[Renderable, list[str]]]  = {}
         self._render_variables: dict[str, Any] = {}
+        if (
+            'design' not in params
+            and self.param.design.default in (None, Design, Native)
+            and config.design is not None
+        ):
+            params['design'] = config.design
         super().__init__(**{
             p: v for p, v in params.items() if p not in _base_config.param or p == 'name'
         })
@@ -192,7 +199,7 @@ class BaseTemplate(param.Parameterized, MimeRenderMixin, ServableMixin, Resource
         location: bool | Location = True
     ):
         # Initialize document
-        document = init_doc(doc or curdoc_locked())
+        document = init_doc(doc or state.curdoc)
 
         self._documents.append(document)
         if document not in state._templates:
@@ -534,7 +541,7 @@ class BaseTemplate(param.Parameterized, MimeRenderMixin, ServableMixin, Resource
         -------
         The template object
         """
-        doc = curdoc_locked()
+        doc = state.curdoc
         if doc and doc.session_context and config.template:
             raise RuntimeError(
                 'Cannot mark template as servable if a global template '
@@ -572,9 +579,13 @@ class TemplateActions(ReactiveHTML):
     as opening and closing a modal.
     """
 
-    open_modal = param.Integer(default=0)
+    open_modal = param.Integer(default=0, doc="""
+        The number of times the open modal action has been triggered.
+        This is used to trigger the open modal script.""")
 
-    close_modal = param.Integer(default=0)
+    close_modal = param.Integer(default=0, doc="""
+        The number of times the close modal action has been triggered.
+        This is used to trigger the close modal script.""")
 
     _template: ClassVar[str] = ""
 
@@ -765,6 +776,8 @@ class BasicTemplate(BaseTemplate):
             state._notifications[document] = self.notifications
         if self._design.theme.bokeh_theme:
             document.theme = self._design.theme.bokeh_theme
+        with set_curdoc(document):
+            config.design = type(self._design)
         return document
 
     def _update_vars(self, *args) -> None:
